QLink-Interface (0.1.0)
=====================================================

Welcome to QLink-Interface's README.

To install the package do:
```bash
make install
```

To verify the installation do:
```
make verify
```

This package defines the service interface of the link layer and provides a magic link layer protocol.
For details about this interface and specific header fields see the paper:
* A Link Layer Protocol for Quantum Networks
  https://arxiv.org/abs/1903.09778
and the QIRG draft:
* The Link Layer service in a Quantum Internet
  https://datatracker.ietf.org/doc/draft-dahlberg-ll-quantum
